lamina-platform - Platform and target detection
This crate provides target architecture and operating system detection and definitions. It’s separated from the main lamina crate to avoid dependency cycles with ras and other components.
Modules
Re-exports
pub use detection::cpu_count;pub use detection::detect_host_architecture_only;pub use detection::detect_host_os;pub use target::HOST_ARCH_LIST;pub use target::Target;pub use target::TargetArchitecture;pub use target::TargetOperatingSystem;pub use detection::detect_host_architecture;Deprecated